@@ -1,11 +1,11 @@
-//! Entity-component registry.
+//! Entity-Component-Resource registry.
 
 mod entity_component;
 mod registry_traits;
+mod resource;
 
-pub mod registry;
 pub mod archetype;
-pub mod resource;
+pub mod registry;
 pub mod storage;
 
 /// Commonly used types.
@@ -13,7 +13,7 @@ pub mod prelude {
     pub use super::archetype::Archetypes;
     pub use super::entity_component::*;
     pub use super::registry::{Registry, RegistryKey};
-    pub use super::resource::{Entities, Components, Resources};
+    pub use super::resource::*;
 
     #[cfg(feature = "muds-derive")]
     pub use muds_derive::{Component, Entity};
